==> cucumber-groovy-1.0.10-sources.jar: cucumber/runtime/groovy/PL.java <==
package cucumber.runtime.groovy;

import groovy.lang.Closure;

import java.util.regex.Pattern;

public class PL {

    public static void Ale(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Ale(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void I(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void I(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Jeśli(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Jeśli(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Jeżeli(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Jeżeli(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Mając(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Mając(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Oraz(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Oraz(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Wtedy(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Wtedy(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zakładając(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Zakładając(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-1.0.14-sources.jar: cucumber/runtime/groovy/PL.java <==
package cucumber.runtime.groovy;

import groovy.lang.Closure;

import java.util.regex.Pattern;

public class PL {

    public static void Ale(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Ale(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Gdy(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Gdy(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void I(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void I(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Jeśli(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Jeśli(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Jeżeli(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Jeżeli(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kiedy(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Kiedy(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Mając(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Mając(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Oraz(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Oraz(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Wtedy(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Wtedy(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zakładając(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Zakładając(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}
